@@ -38,8 +38,8 @@ def _conn_execute(self, query, *args):
     return cursor
 
 
-def _create_lookup_dict(descr):
-    return {info[0]: index for index, info in enumerate(descr)}
+def _create_lookup_dict(description):
+    return {info[0]: index for index, info in enumerate(description)}
         
 
 class DictRow(list):
@@ -57,6 +57,8 @@ class DictRow(list):
 
 
 def _cursor_fetchone(self):
+    if self.description is None:
+        return None
     lookup = _create_lookup_dict(self.description)
     row = self._fetchone()
     if row:
@@ -68,9 +70,11 @@ def _cursor_fetchall(self):
 
 
 def _cursor_iter(self):
-	lookup = _create_lookup_dict(self.description)
-	while (row := self._fetchone()) is not None:
-		yield DictRow(row, lookup)
+    if self.description is None:
+        return
+    lookup = _create_lookup_dict(self.description)
+    while (row := self._fetchone()) is not None:
+        yield DictRow(row, lookup)
 
 
 def get_uri(dirname="data/postgresqlite", driver="pg8000"):
